summaryrefslogtreecommitdiff
path: root/board/vell/fw_config.h
diff options
context:
space:
mode:
Diffstat (limited to 'board/vell/fw_config.h')
-rw-r--r--board/vell/fw_config.h47
1 files changed, 10 insertions, 37 deletions
diff --git a/board/vell/fw_config.h b/board/vell/fw_config.h
index fea6c9a8da..324057a8e9 100644
--- a/board/vell/fw_config.h
+++ b/board/vell/fw_config.h
@@ -3,52 +3,25 @@
* found in the LICENSE file.
*/
-#ifndef __BOARD_BRYA_FW_CONFIG_H_
-#define __BOARD_BRYA_FW_CONFIG_H_
+#ifndef __BOARD_VELL_FW_CONFIG_H_
+#define __BOARD_VELL_FW_CONFIG_H_
#include <stdint.h>
/****************************************************************************
* CBI FW_CONFIG layout for Brya board.
*
* Source of truth is the project/brya/brya/config.star configuration file.
*/
-
-enum ec_cfg_usb_db_type {
- DB_USB_ABSENT = 0,
- DB_USB3_PS8815 = 1,
- DB_USB_ABSENT2 = 15
-};
-
-enum ec_cfg_keyboard_backlight_type {
- KEYBOARD_BACKLIGHT_DISABLED = 0,
- KEYBOARD_BACKLIGHT_ENABLED = 1
-};
-
-union brya_cbi_fw_config {
+union vell_cbi_fw_config {
struct {
- enum ec_cfg_usb_db_type usb_db : 4;
- uint32_t sd_db : 2;
uint32_t lte_db : 1;
- enum ec_cfg_keyboard_backlight_type kb_bl : 1;
- uint32_t audio : 3;
- uint32_t reserved_1 : 21;
+ uint32_t kb_color : 1;
+ uint32_t storage_nand : 1;
+ uint32_t wifi_sar_id : 2;
+ uint32_t reserved_1 : 27;
};
uint32_t raw_value;
};
-/**
- * Read the cached FW_CONFIG. Guaranteed to have valid values.
- *
- * @return the FW_CONFIG for the board.
- */
-union brya_cbi_fw_config get_fw_config(void);
-
-/**
- * Get the USB daughter board type from FW_CONFIG.
- *
- * @return the USB daughter board type.
- */
-enum ec_cfg_usb_db_type ec_cfg_usb_db_type(void);
-
-#endif /* __BOARD_BRYA_FW_CONFIG_H_ */
+#endif /* __BOARD_VELL_FW_CONFIG_H_ */
@@ -3,52 +3,25 @@
#include <stdint.h>
/****************************************************************************
- * CBI FW_CONFIG layout for Brya board.
+ * CBI FW_CONFIG layout for Vell board.
*
@@ -3,52 +3,25 @@
*
- * Source of truth is the project/brya/brya/config.star configuration file.
+ * Source of truth is the project/brya/vell/config.star configuration file.
*/